[][src]Trait snarkvm_models::gadgets::r1cs::ConstraintSystem

pub trait ConstraintSystem<F: Field>: Sized {
    type Root: ConstraintSystem<F>;
    pub fn alloc<FN, A, AR>(
        &mut self,
        annotation: A,
        f: FN
    ) -> Result<Variable, SynthesisError>
    where
        FN: FnOnce() -> Result<F, SynthesisError>,
        A: FnOnce() -> AR,
        AR: AsRef<str>
;
pub fn alloc_input<FN, A, AR>(
        &mut self,
        annotation: A,
        f: FN
    ) -> Result<Variable, SynthesisError>
    where
        FN: FnOnce() -> Result<F, SynthesisError>,
        A: FnOnce() -> AR,
        AR: AsRef<str>
;
pub fn enforce<A, AR, LA, LB, LC>(
        &mut self,
        annotation: A,
        a: LA,
        b: LB,
        c: LC
    )
    where
        A: FnOnce() -> AR,
        AR: AsRef<str>,
        LA: FnOnce(LinearCombination<F>) -> LinearCombination<F>,
        LB: FnOnce(LinearCombination<F>) -> LinearCombination<F>,
        LC: FnOnce(LinearCombination<F>) -> LinearCombination<F>
;
pub fn push_namespace<NR, N>(&mut self, name_fn: N)
    where
        NR: AsRef<str>,
        N: FnOnce() -> NR
;
pub fn pop_namespace(&mut self);
pub fn get_root(&mut self) -> &mut Self::Root;
pub fn num_constraints(&self) -> usize; pub fn one() -> Variable { ... }
pub fn ns<NR, N>(&mut self, name_fn: N) -> Namespace<'_, F, Self::Root>
    where
        NR: AsRef<str>,
        N: FnOnce() -> NR
, { ... } }

Represents a constraint system which can have new variables allocated and constrains between them formed.

Associated Types

type Root: ConstraintSystem<F>[src]

Represents the type of the "root" of this constraint system so that nested namespaces can minimize indirection.

Loading content...

Required methods

pub fn alloc<FN, A, AR>(
    &mut self,
    annotation: A,
    f: FN
) -> Result<Variable, SynthesisError> where
    FN: FnOnce() -> Result<F, SynthesisError>,
    A: FnOnce() -> AR,
    AR: AsRef<str>, 
[src]

Allocate a private variable in the constraint system. The provided function is used to determine the assignment of the variable. The given annotation function is invoked in testing contexts in order to derive a unique name for this variable in the current namespace.

pub fn alloc_input<FN, A, AR>(
    &mut self,
    annotation: A,
    f: FN
) -> Result<Variable, SynthesisError> where
    FN: FnOnce() -> Result<F, SynthesisError>,
    A: FnOnce() -> AR,
    AR: AsRef<str>, 
[src]

Allocate a public variable in the constraint system. The provided function is used to determine the assignment of the variable.

pub fn enforce<A, AR, LA, LB, LC>(&mut self, annotation: A, a: LA, b: LB, c: LC) where
    A: FnOnce() -> AR,
    AR: AsRef<str>,
    LA: FnOnce(LinearCombination<F>) -> LinearCombination<F>,
    LB: FnOnce(LinearCombination<F>) -> LinearCombination<F>,
    LC: FnOnce(LinearCombination<F>) -> LinearCombination<F>, 
[src]

Enforce that A * B = C. The annotation function is invoked in testing contexts in order to derive a unique name for the constraint in the current namespace.

pub fn push_namespace<NR, N>(&mut self, name_fn: N) where
    NR: AsRef<str>,
    N: FnOnce() -> NR, 
[src]

Create a new (sub)namespace and enter into it. Not intended for downstream use; use namespace instead.

pub fn pop_namespace(&mut self)[src]

Exit out of the existing namespace. Not intended for downstream use; use namespace instead.

pub fn get_root(&mut self) -> &mut Self::Root[src]

Gets the "root" constraint system, bypassing the namespacing. Not intended for downstream use; use namespace instead.

pub fn num_constraints(&self) -> usize[src]

Output the number of constraints in the system.

Loading content...

Provided methods

pub fn one() -> Variable[src]

Return the "one" input variable

pub fn ns<NR, N>(&mut self, name_fn: N) -> Namespace<'_, F, Self::Root> where
    NR: AsRef<str>,
    N: FnOnce() -> NR, 
[src]

Begin a namespace for this constraint system.

Loading content...

Implementations on Foreign Types

impl<F: Field, CS: ConstraintSystem<F>> ConstraintSystem<F> for &mut CS[src]

Convenience implementation of ConstraintSystem for mutable references to constraint systems.

type Root = CS::Root

Loading content...

Implementors

impl<ConstraintF: Field> ConstraintSystem<ConstraintF> for ConstraintCounter[src]

type Root = Self

impl<F: Field> ConstraintSystem<F> for TestConstraintSystem<F>[src]

type Root = Self

impl<F: Field, CS: ConstraintSystem<F>> ConstraintSystem<F> for Namespace<'_, F, CS>[src]

type Root = CS::Root

Loading content...