[][src]Enum snarkvm_models::gadgets::utilities::boolean::Boolean

pub enum Boolean {
    Is(AllocatedBit),
    Not(AllocatedBit),
    Constant(bool),
}

This is a boolean value which may be either a constant or an interpretation of an AllocatedBit.

Variants

Existential view of the boolean variable

Negated view of the boolean variable

Constant(bool)

Constant (not an allocated variable)

Implementations

impl Boolean[src]

pub fn get_value(&self) -> Option<bool>[src]

pub fn lc<F: Field>(&self, one: Variable, coeff: F) -> LinearCombination<F>[src]

pub fn constant_u8_vec<F: Field, CS: ConstraintSystem<F>>(
    cs: &mut CS,
    values: &[u8]
) -> Vec<Self>
[src]

Construct a boolean vector from a vector of u8

pub fn constant(b: bool) -> Self[src]

Construct a boolean from a known constant.

pub fn not(&self) -> Self[src]

Return a negated interpretation of this boolean.

pub fn xor<'a, F, CS>(
    cs: CS,
    a: &'a Self,
    b: &'a Self
) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Perform XOR over two boolean operands.

pub fn or<'a, F, CS>(
    cs: CS,
    a: &'a Self,
    b: &'a Self
) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Perform OR over two boolean operands.

pub fn and<'a, F: Field, CS: ConstraintSystem<F>>(
    cs: CS,
    a: &'a Self,
    b: &'a Self
) -> Result<Self, SynthesisError>
[src]

Perform AND over two boolean operands.

pub fn kary_and<F, CS>(cs: CS, bits: &[Self]) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Perform AND over all the given boolean operands.

pub fn enforce_nand<F, CS>(cs: CS, bits: &[Self]) -> Result<(), SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Asserts that at least one operand is false.

pub fn enforce_in_field<F, CS, NativeF: PrimeField>(
    cs: CS,
    bits: &[Self]
) -> Result<(), SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Asserts that this bit_gadget representation is "in the field" when interpreted in big endian.