[][src]Struct snarkvm_models::gadgets::utilities::boolean::AllocatedBit

pub struct AllocatedBit { /* fields omitted */ }

Represents a variable in the constraint system which is guaranteed to be either zero or one.

Implementations

impl AllocatedBit[src]

pub fn get_value(&self) -> Option<bool>[src]

pub fn get_variable(&self) -> Variable[src]

pub fn xor<F, CS>(cs: CS, a: &Self, b: &Self) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Performs an XOR operation over the two operands, returning an AllocatedBit.

pub fn and<F, CS>(cs: CS, a: &Self, b: &Self) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Performs an AND operation over the two operands, returning an AllocatedBit.

pub fn or<F, CS>(cs: CS, a: &Self, b: &Self) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Performs an OR operation over the two operands, returning an AllocatedBit.

pub fn and_not<F, CS>(
    cs: CS,
    a: &Self,
    b: &Self
) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Calculates a AND (NOT b).

pub fn nor<F, CS>(cs: CS, a: &Self, b: &Self) -> Result<Self, SynthesisError> where
    F: Field,
    CS: ConstraintSystem<F>, 
[src]

Calculates (NOT a) AND (NOT b).